{
    'name': 'Anonymous portal',
    'description': """
Allow anonymous to Access Portal.
=================================
 """,
    'author': 'OpenERP SA',
    'version': '1.0',
    'category': 'Hidden',
    'website': 'http://www.openerp.com',
    'installable': True,
    'depends': ['portal', 'web'],
    'data': [
        'security/ir.model.access.csv',
        'portal_anonymous_data.xml',
    ],
    'js': ['static/src/js/portal_anonymous.js'],
    'qweb': ['static/src/xml/portal_anonymous.xml'],
}



#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `portal_anonymous` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-portal-anonymous",
    version = "7.0.355",
    description = "Anonymous portal",
    long_description = 
"""

Allow anonymous to Access Portal.
=================================
 
""",
    url = "http://www.openerp.com",
    author = "OpenERP SA",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.portal_anonymous': ".",
    },
    packages = ["openerp.addons.portal_anonymous"],
    package_data = {
        'openerp.addons.portal_anonymous': ["i18n/*.po*","portal_anonymous_data.xml","static/src/xml/portal_anonymous.xml","static/src/js/portal_anonymous.js","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/ru.po","i18n/en_GB.po","i18n/cs.po","i18n/fi.po","i18n/pt_BR.po","i18n/ro.po","i18n/es.po","i18n/mn.po","i18n/nl.po","i18n/sv.po","i18n/tr.po","i18n/en_AU.po","i18n/de.po","i18n/lt.po","i18n/hu.po","i18n/mk.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/th.po","i18n/ar.po","i18n/pt.po","security/ir.model.access.csv","security/ir.model.access.csv","portal_anonymous_data.xml","static/src/xml/portal_anonymous.xml","static/src/js/portal_anonymous.js"],
    },
    install_requires = ["openerp-portal","openerp-web"],
    tests_require = ["unittest2"],
)
